==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/BundleLookupConditionBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BundleLookupConditionBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition,io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionBuilder>{
  public BundleLookupConditionBuilder() {
    this(false);
  }
  public BundleLookupConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new BundleLookupCondition(), validationEnabled);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BundleLookupCondition(), validationEnabled);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance) {
    this(fluent, instance, false);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance) {
    this(instance,false);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition build() {
    BundleLookupCondition buildable = new BundleLookupCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BundleLookupConditionBuilder that = (BundleLookupConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/BundleLookupConditionBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BundleLookupConditionBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition,io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionBuilder>{
  public BundleLookupConditionBuilder() {
    this(false);
  }
  public BundleLookupConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new BundleLookupCondition(), validationEnabled);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BundleLookupCondition(), validationEnabled);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance) {
    this(fluent, instance, false);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance) {
    this(instance,false);
  }
  public BundleLookupConditionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.BundleLookupCondition build() {
    BundleLookupCondition buildable = new BundleLookupCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BundleLookupConditionBuilder that = (BundleLookupConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
